@@ -60,7 +60,11 @@
 (defun evil-textobj-tree-sitter--use-builtin-treesitter ()
   "Return non-nil if we should use builtin treesitter."
   (and evil-textobj-tree-sitter--can-use-builtin-treesit
-       (string-suffix-p "-ts-mode" (symbol-name major-mode))))
+       (let ((major-mode-name (symbol-name major-mode)))
+         (or (string-suffix-p "-ts-mode" major-mode-name)
+             (and (boundp 'rust-mode-treesitter-derive)
+                  rust-mode-treesitter-derive
+                  (string= "rustic-mode" major-mode-name))))))
 
 (defun evil-textobj-tree-sitter--get-queries-dir ()
   "Get the queries directory.
@@ -102,7 +106,7 @@ Currently treesit queries are different from queries for elisp-tree-sitter."
                           (javascript-mode . "javascript")
                           (javascript-ts-mode . "javascript")
                           (js-mode . "javascript")
-                          (js-ts-mode . "js")
+                          (js-ts-mode . "javascript")
                           (js2-mode . "javascript")
                           (js3-mode . "javascript")
                           (julia-mode . "julia")
@@ -123,6 +127,8 @@ Currently treesit queries are different from queries for elisp-tree-sitter."
                           (sh-mode . "bash")
                           (bash-ts-mode . "sh")
                           (shell-script-mode . "bash")
+                          (tsx-mode . "tsx")
+                          (tsx-ts-mode . "tsx")
                           (typescript-mode . "typescript")
                           (typescript-ts-mode . "typescript")
                           (verilog-mode . "verilog")
